@@ -6,14 +6,15 @@ for HTML.
 of the system.
 """
 
-import urllib
-
 from tiddlyweb import __version__ as VERSION
 from tiddlyweb.serializations import SerializationInterface
 from tiddlyweb.web.util import encode_name, escape_attribute_value, tiddler_url
 from tiddlyweb.wikitext import render_wikitext
 
-HEADER = """<!DOCTYPE HTML>
+from tiddlyweb.fixups import quote
+
+
+HEADER = u"""<!DOCTYPE HTML>
 <html>
 <head>
 <meta charset="UTF-8">
@@ -28,7 +29,7 @@ HEADER = """<!DOCTYPE HTML>
 <div id="content">
 """
 
-FOOTER = """
+FOOTER = u"""
 </div>
 <div id="footer">
 <div id="badge">This is <a href="http://tiddlyweb.com/">TiddlyWeb</a>
@@ -158,12 +159,10 @@ class Serialization(SerializationInterface):
         lines = []
         for bag, filter_string in recipe.get_recipe():
             line = '<li><a href="'
-            if not isinstance(bag, basestring):
-                bag = bag.name
             line += '%s/bags/%s/tiddlers' % (
                     self._server_prefix(), encode_name(bag))
             if filter_string:
-                line += '?%s' % urllib.quote(
+                line += '?%s' % quote(
                         filter_string.encode('utf-8'), safe=':=;')
             line += '">bag: %s filter:%s</a></li>' % (bag, filter_string)
             lines.append(line)
@@ -270,9 +269,7 @@ class Serialization(SerializationInterface):
             links = []
             query_string = self.environ.get('QUERY_STRING', '')
             if query_string:
-                # By now there would have already been a failure if
-                # if the query string is not valid utf-8.
-                query_string = '?%s' % unicode(query_string, 'utf-8')
+                query_string = '?%s' % query_string
             for extension in extension_types:
                 link = '<a href="%s.%s%s">%s</a>' % (representation_link,
                         extension, query_string, extension)
